@@ -1,12 +1,4 @@
-#ifdef _MSC_VER
-	#include "..\..\..\IMat\RFunc.h"	 
-	#include "..\..\..\IMat\IMat.h"
-	#include "..\..\..\IMat\ITens.h"
-#else
-	#include "RFunc.h"	 
-	#include "IMat.h"
-	#include "ITens.h"
-#endif
+#include "restr.h"
 
 	class TClust
 	{
